@@ -1,10 +1,16 @@
 import json
 import time
 import requests
-from urllib import urlencode
 import hashlib
 import re
-import HTMLParser
+
+# handle python 2 and python 3 imports
+try:
+    from urllib.parse import urlencode
+    import html.parser as htmlparser
+except ImportError:
+    from urllib import urlencode
+    import HTMLParser as htmlparser
 
 base_uri = 'app.imdb.com'
 api_key = '2wex6aeu6a8q9e49k7sfvufd6rhh0n'
@@ -19,7 +25,7 @@ class Imdb(object):
 
         if options is None:
             options = {}
-            
+
         self.options = options
         if options.get('anonymize') is True:
             self.base_uri = 'youtubeproxy.org/default.aspx?prx=https://{0}'.format(self.base_uri)
@@ -40,7 +46,7 @@ class Imdb(object):
                           "locale": self.locale,
                           "timestamp": int(time.time())}
 
-        query_params = dict(default_params.items() + params.items())
+        query_params = dict(list(default_params.items()) + list(params.items()))
         query_params = urlencode(query_params)
         return 'https://{0}{1}?{2}'.format(self.base_uri, path, query_params)
 
@@ -55,7 +61,7 @@ class Imdb(object):
             return False
 
         #get the full cast information, add key if not present
-        result["data"][unicode("credits")] = self.get_credits(imdb_id)
+        result["data"][str("credits")] = self.get_credits(imdb_id)
 
         if self.exclude_episodes is True and result["data"].get('type') == 'tv_episode':
             return False
@@ -117,7 +123,7 @@ class Imdb(object):
                 'title_substring']
         title_results = []
 
-        html_unescape = HTMLParser.HTMLParser().unescape
+        html_unescape = htmlparser.HTMLParser().unescape
 
         # Loop through all results and build a list with popular matches first
         for key in keys:
@@ -250,8 +256,7 @@ class Title(object):
         if self.data.get('credits'):
             for credit in self.data['credits']:
                 """
-                Possible tokens
-                directors, cast, writers, producers and others
+                Possible tokens: directors, cast, writers, producers and others
                 """
                 for person in credit['list']:
                     person_extra = {'token': credit.get('token'),
@@ -266,5 +271,5 @@ class Title(object):
         # Trailers
         self.trailers = {}
         if 'trailer' in self.data and 'encodings' in self.data['trailer']:
-            for k, v in self.data['trailer']['encodings'].items():
-                self.trailers[v['format']] = v['url']
\ No newline at end of file
+            for k, v in list(self.data['trailer']['encodings'].items()):
+                self.trailers[v['format']] = v['url']
